@@ -175,7 +175,17 @@ void ConnectionEditor::initializeMenu()
 
     actionCollection()->addAction("add_connection", m_menu);
 
-    KAction * kAction = new KAction(KIcon("configure"), i18n("Edit..."), this);
+    KAction * kAction = new KAction(KIcon("network-connect"), i18n("Connect"), this);
+    kAction->setEnabled(false);
+    connect(kAction, SIGNAL(triggered()), this, SLOT(connectConnection()));
+    actionCollection()->addAction("connect_connection", kAction);
+
+    kAction = new KAction(KIcon("network-disconnect"), i18n("Disconnect"), this);
+    kAction->setEnabled(false);
+    connect(kAction, SIGNAL(triggered()), this, SLOT(disconnectConnection()));
+    actionCollection()->addAction("disconnect_connection", kAction);
+
+    kAction = new KAction(KIcon("configure"), i18n("Edit..."), this);
     kAction->setEnabled(false);
     connect(kAction, SIGNAL(triggered()), SLOT(editConnection()));
     actionCollection()->addAction("edit_connection", kAction);
@@ -276,6 +286,21 @@ void ConnectionEditor::connectConnection()
     m_handler->activateConnection(connectionPath, devicePath, specificPath);
 }
 
+void ConnectionEditor::dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
+{
+    QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
+    if (currentIndex.isValid()) {
+        for (int i = topLeft.row(); i <= bottomRight.row(); i++) {
+            QModelIndex index = m_editor->connectionsWidget->model()->index(i, 0);
+            if (index.isValid() && index == currentIndex) {
+                // Re-check enabled/disabled actions
+                slotItemClicked(currentIndex);
+                break;
+            }
+        }
+    }
+}
+
 void ConnectionEditor::disconnectConnection()
 {
     const QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
@@ -303,13 +328,12 @@ void ConnectionEditor::editConnection()
 void ConnectionEditor::initializeConnections()
 {
     EditorIdentityModel * model = new EditorIdentityModel(this);
-
     EditorProxyModel * filterModel = new EditorProxyModel(this);
     filterModel->setSourceModel(model);
+    connect(filterModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),SLOT(dataChanged(QModelIndex,QModelIndex)));
 
     m_editor->connectionsWidget->setModel(filterModel);
     m_editor->ktreewidgetsearchline->setProxy(filterModel);
-
     m_editor->connectionsWidget->header()->setResizeMode(0, QHeaderView::Stretch);
 }
 
@@ -349,9 +373,9 @@ void ConnectionEditor::slotContextMenuRequested(const QPoint&)
     const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
 
     if (isAvailable && !isActive) {
-        menu->addAction(KIcon("user-online"), i18n("Connect"), this, SLOT(connectConnection()));
+        menu->addAction(actionCollection()->action("connect_connection"));
     } else if (isAvailable && isActive) {
-        menu->addAction(KIcon("user-offline"), i18n("Disconnect"), this, SLOT(disconnectConnection()));
+        menu->addAction(actionCollection()->action("disconnect_connection"));
     }
     menu->addAction(actionCollection()->action("edit_connection"));
     menu->addAction(actionCollection()->action("delete_connection"));
@@ -367,11 +391,19 @@ void ConnectionEditor::slotItemClicked(const QModelIndex &index)
     qDebug() << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
 
     if (index.parent().isValid()) { // category
+        actionCollection()->action("connect_connection")->setEnabled(false);
+        actionCollection()->action("disconnect_connection")->setEnabled(false);
         actionCollection()->action("edit_connection")->setEnabled(false);
         actionCollection()->action("delete_connection")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
     } else {                       //connection
+        const bool isActive = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
+        const bool isActivating = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activating;
+        const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
+
+        actionCollection()->action("connect_connection")->setEnabled(isAvailable && !isActive && !isActivating);
+        actionCollection()->action("disconnect_connection")->setEnabled(isAvailable && (isActive || isActivating));
         actionCollection()->action("edit_connection")->setEnabled(true);
         actionCollection()->action("delete_connection")->setEnabled(true);
         const bool isVpn = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(index.data(NetworkModel::TypeRole).toUInt()) ==
