@@ -25,20 +25,19 @@
 #include <QObject>
 #include <QDBusPendingCallWatcher>
 
-#include "config.h"
+#include <config.h>
 
-#ifdef MODEMMANAGERQT_ONE
 #include <ModemManager/ModemManager.h>
 #include <ModemManagerQt/modem.h>
-#endif
-#include <kdemacros.h>
+
+#include "plasmanm_export.h"
 
 class ModemMonitorPrivate;
 
 /**
  * Monitors modem hardware and provides a PIN unlock dialog
  */
-class KDE_EXPORT ModemMonitor : public QObject
+class PLASMA_NM_EXPORT ModemMonitor : public QObject
 {
     Q_OBJECT
     Q_DECLARE_PRIVATE(ModemMonitor)
@@ -47,11 +46,7 @@ public:
     virtual ~ModemMonitor();
 private slots:
     void modemAdded(const QString&);
-#ifdef MODEMMANAGERQT_ONE
     void requestPin(MMModemLock lock);
-#else
-    void requestPin(const QString &);
-#endif
     void onSendPinArrived(QDBusPendingCallWatcher *);
 private:
     ModemMonitorPrivate * d_ptr;
