@@ -74,10 +74,10 @@ void PasswordDialog::setupGenericUi(const ConnectionSettings &connectionSettings
 
     Setting::SettingType connectionType = setting->type();
     if (wifi && (connectionType == Setting::WirelessSecurity || connectionType == Setting::Security8021x)) {
-        const QString ssid = wifi->ssid();
+        const QString ssid = QString::fromUtf8(wifi->ssid());
         ui->labelText->setText(i18n("For accessing the wireless network '%1' you need to provide a password below", ssid));
     } else {
-        ui->labelText->setText(i18n("Please provide the password for activating connection '%1'", connectionSettings.name()));
+        ui->labelText->setText(i18n("Please provide the password for activating connection '%1'", connectionSettings.id()));
     }
 
     ui->password->setPasswordMode(true);
