@@ -21,6 +21,8 @@
 #ifndef PLASMA_NM_HANDLER_H
 #define PLASMA_NM_HANDLER_H
 
+#include <QDBusInterface>
+
 #include <NetworkManagerQt/Connection>
 
 #include "plasmanm_export.h"
@@ -97,6 +99,7 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void editDialogAccepted();
+    void initKdedModule();
     void replyFinished(QDBusPendingCallWatcher * watcher);
 
 private:
@@ -109,6 +112,7 @@ private:
     QString m_tmpSpecificPath;
 
     bool isBtEnabled();
+    QDBusInterface m_agentIface;
 };
 
 #endif // PLASMA_NM_HANDLER_H
