@@ -1,22 +1,22 @@
 /*
-Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
-Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
+    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
+    Copyright 2013 Lukas Tinkl <ltinkl@redhat.com>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
 
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "openconnectui.h"
@@ -60,6 +60,11 @@ QString OpenconnectUiPlugin::supportedFileExtensions() const
     return QString();
 }
 
+QMessageBox::StandardButtons OpenconnectUiPlugin::suggestedAuthDialogButtons() const
+{
+    return QMessageBox::Close;
+}
+
 NMVariantMapMap OpenconnectUiPlugin::importConnectionSettings(const QString &fileName)
 {
     Q_UNUSED(fileName);
