@@ -70,7 +70,6 @@ K_EXPORT_PLUGIN(OpenVpnUiPluginFactory("plasmanetworkmanagement_openvpnui"))
 #define TLS_CLIENT_TAG "tls-client"
 #define TLS_REMOTE_TAG "tls-remote"
 #define TUNMTU_TAG "tun-mtu"
-#define REDIRECT_GATEWAY_TAG "redirect-gateway"
 #define KEY_DIRECTION_TAG "key-direction"
 
 #define BEGIN_KEY_CA_TAG "<ca>"
@@ -207,7 +206,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
     bool proxy_set = false;
     bool have_pass = false;
     bool have_sk = false;
-    bool have_redirect_gateway = false;
     int key_direction = -1;
 
     QTextStream in(&impFile);
@@ -499,10 +497,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
             }
             continue;
         }
-        if (key_value[0] == REDIRECT_GATEWAY_TAG) {
-            have_redirect_gateway = true;
-            continue;
-        }
         if (key_value[0] == KEY_DIRECTION_TAG) {
             if (key_value.count() == 2) {
                 key_direction = key_value[1].toInt();
@@ -562,12 +556,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
             continue;
         }
     }
-    // NetworkManager set vpn connections as default route by default. If the
-    // imported file does not contain "redirect-gateway" entry then set the
-    // connection as never default.
-    if (!have_redirect_gateway) {
-        ipv4Data.insert(NM_SETTING_IP4_CONFIG_NEVER_DEFAULT, "true");
-    }
     if (!have_client && !have_sk) {
         mError = VpnUiPlugin::Error;
         mErrorMessage = i18n("File %1 is not a valid OpenVPN's client configuration file", fileName);
@@ -819,10 +807,6 @@ bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionS
     }
     // Export never default setting.
     NetworkManager::Ipv4Setting::Ptr ipv4Setting = connection->setting(NetworkManager::Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
-    if (!ipv4Setting->neverDefault()) {
-        line = QString(REDIRECT_GATEWAY_TAG) + '\n';
-        expFile.write(line.toLatin1());
-    }
     // Export X-NM-Routes
     if (!ipv4Setting->routes().isEmpty()) {
         QString routes;
